==> ukui-screensaver_2.1.1.orig.tar.gz: ukui-screensaver/i18n_ts/es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<context>
    <name>AuthDialog</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Formar</translation>
    </message>
    <message>
        <source>More Devices</source>
        <translation type="obsolete">Más dispositivos</translation>
    </message>
    <message>
        <source>Biometric</source>
        <translation type="obsolete">Biometrico</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="obsolete">Contraseña</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation>Procesar de nuevo</translation>
    </message>
    <message>
        <source>UnLock</source>
        <translation type="obsolete">Desbloquear</translation>
    </message>
    <message>
        <source>LoggedIn</source>
        <translation type="obsolete">Conectado</translation>
    </message>
    <message>
        <source>Password Incorrect, Please try again</source>
        <translation>Contraseña incorrecta, por favor intente de nuevo</translation>
    </message>
    <message>
        <source>Password: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Account locked %1 minutes due to %2 fail attempts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Authentication failure,there are still %1 remaining opportunities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Biometric Authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password Authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other Devices</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BioAuthWidget</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Formar</translation>
    </message>
    <message>
        <source>TextLabel</source>
        <translation type="obsolete">TextLabel</translation>
    </message>
    <message>
        <source>More</source>
        <translation type="obsolete">Más</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation type="obsolete">Procesar de nuevo</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="obsolete">Contraseña</translation>
    </message>
</context>
<context>
    <name>BioDevices</name>
    <message>
        <source>FingerPrint</source>
        <translation type="obsolete">Huella dactilar</translation>
    </message>
    <message>
        <source>FingerVein</source>
        <translation type="obsolete">FingerVein</translation>
    </message>
    <message>
        <source>Iris</source>
        <translation type="obsolete">Iris</translation>
    </message>
    <message>
        <source>Face</source>
        <translation type="obsolete">Cara</translation>
    </message>
    <message>
        <source>VoicePrint</source>
        <translation type="obsolete">Impresión de voz</translation>
    </message>
</context>
<context>
    <name>BioDevicesWidget</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Formar</translation>
    </message>
    <message>
        <source>Please select other biometric devices</source>
        <translation type="obsolete">Por favor seleccione otros dispositivos biométricos</translation>
    </message>
    <message>
        <source>Device Type:</source>
        <translation type="obsolete">Tipo de dispositivo:</translation>
    </message>
    <message>
        <source>Device Name:</source>
        <translation type="obsolete">Nombre del dispositivo:</translation>
    </message>
</context>
<context>
    <name>BiometricAuthWidget</name>
    <message>
        <source>Current device: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Identify failed, Please retry.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BiometricDevicesWidget</name>
    <message>
        <source>Please select the biometric device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Device type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Device name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeviceType</name>
    <message>
        <source>FingerPrint</source>
        <translation type="unfinished">Huella dactilar</translation>
    </message>
    <message>
        <source>FingerVein</source>
        <translation type="unfinished">FingerVein</translation>
    </message>
    <message>
        <source>Iris</source>
        <translation type="unfinished">Iris</translation>
    </message>
    <message>
        <source>Face</source>
        <translation type="unfinished">Cara</translation>
    </message>
    <message>
        <source>VoicePrint</source>
        <translation type="unfinished">Impresión de voz</translation>
    </message>
</context>
<context>
    <name>KeyboardWidget</name>
    <message>
        <source>KeyboardWidget</source>
        <translation>TecladoWidget</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>Form</source>
        <translation>Formar</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Fecha</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Hora</translation>
    </message>
    <message>
        <source>Guest</source>
        <translation>Huésped</translation>
    </message>
    <message>
        <source>SwitchUser</source>
        <translation>Cambiar de usuario</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Start command for the ukui ScreenSaver.</source>
        <translation>Comando de inicio para el protector de pantalla de ukui.</translation>
    </message>
    <message>
        <source>lock the screen immediately</source>
        <translation>bloquea la pantalla inmediatamente</translation>
    </message>
    <message>
        <source>Dialog for the ukui ScreenSaver.</source>
        <translation>Diálogo para el protector de pantalla de ukui.</translation>
    </message>
    <message>
        <source>activated by session idle signal</source>
        <translation>activado por la señal de inactividad de la sesión</translation>
    </message>
</context>
</TS>

==> ukui-screensaver_3.0.1.orig.tar.gz: ukui-screensaver/i18n_ts/es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>AuthDialog</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Formar</translation>
    </message>
    <message>
        <source>More Devices</source>
        <translation type="obsolete">Más dispositivos</translation>
    </message>
    <message>
        <source>Biometric</source>
        <translation type="obsolete">Biometrico</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="obsolete">Contraseña</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation>Procesar de nuevo</translation>
    </message>
    <message>
        <source>UnLock</source>
        <translation type="obsolete">Desbloquear</translation>
    </message>
    <message>
        <source>LoggedIn</source>
        <translation type="obsolete">Conectado</translation>
    </message>
    <message>
        <source>Password Incorrect, Please try again</source>
        <translation>Contraseña incorrecta, por favor intente de nuevo</translation>
    </message>
    <message>
        <source>Password: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Biometric Authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password Authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other Devices</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BioAuthWidget</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Formar</translation>
    </message>
    <message>
        <source>TextLabel</source>
        <translation type="obsolete">TextLabel</translation>
    </message>
    <message>
        <source>More</source>
        <translation type="obsolete">Más</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation type="obsolete">Procesar de nuevo</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="obsolete">Contraseña</translation>
    </message>
</context>
<context>
    <name>BioDevices</name>
    <message>
        <source>FingerPrint</source>
        <translation type="obsolete">Huella dactilar</translation>
    </message>
    <message>
        <source>FingerVein</source>
        <translation type="obsolete">FingerVein</translation>
    </message>
    <message>
        <source>Iris</source>
        <translation type="obsolete">Iris</translation>
    </message>
    <message>
        <source>Face</source>
        <translation type="obsolete">Cara</translation>
    </message>
    <message>
        <source>VoicePrint</source>
        <translation type="obsolete">Impresión de voz</translation>
    </message>
</context>
<context>
    <name>BioDevicesWidget</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Formar</translation>
    </message>
    <message>
        <source>Please select other biometric devices</source>
        <translation type="obsolete">Por favor seleccione otros dispositivos biométricos</translation>
    </message>
    <message>
        <source>Device Type:</source>
        <translation type="obsolete">Tipo de dispositivo:</translation>
    </message>
    <message>
        <source>Device Name:</source>
        <translation type="obsolete">Nombre del dispositivo:</translation>
    </message>
</context>
<context>
    <name>BiometricAuthWidget</name>
    <message>
        <source>Current device: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Identify failed, Please retry.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BiometricDevicesWidget</name>
    <message>
        <source>Please select the biometric device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Device type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Device name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeviceType</name>
    <message>
        <source>FingerPrint</source>
        <translation type="unfinished">Huella dactilar</translation>
    </message>
    <message>
        <source>FingerVein</source>
        <translation type="unfinished">FingerVein</translation>
    </message>
    <message>
        <source>Iris</source>
        <translation type="unfinished">Iris</translation>
    </message>
    <message>
        <source>Face</source>
        <translation type="unfinished">Cara</translation>
    </message>
    <message>
        <source>VoicePrint</source>
        <translation type="unfinished">Impresión de voz</translation>
    </message>
</context>
<context>
    <name>KeyboardWidget</name>
    <message>
        <source>KeyboardWidget</source>
        <translation>TecladoWidget</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>Form</source>
        <translation>Formar</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Fecha</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Hora</translation>
    </message>
    <message>
        <source>Guest</source>
        <translation>Huésped</translation>
    </message>
    <message>
        <source>SwitchUser</source>
        <translation type="vanished">Cambiar de usuario</translation>
    </message>
</context>
<context>
    <name>PowerManager</name>
    <message>
        <source>SwitchUser</source>
        <translation type="obsolete">Cambiar de usuario</translation>
    </message>
    <message>
        <source>Lock Screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Power Off</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The screensaver is active.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The screensaver is inactive.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Screensaver</name>
    <message>
        <source>Set as desktop wallpaper</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatic switching</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SleepTime</name>
    <message>
        <source>You have rested:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Start command for the ukui ScreenSaver.</source>
        <translation>Comando de inicio para el protector de pantalla de ukui.</translation>
    </message>
    <message>
        <source>lock the screen immediately</source>
        <translation>bloquea la pantalla inmediatamente</translation>
    </message>
    <message>
        <source>Dialog for the ukui ScreenSaver.</source>
        <translation>Diálogo para el protector de pantalla de ukui.</translation>
    </message>
    <message>
        <source>activated by session idle signal</source>
        <translation>activado por la señal de inactividad de la sesión</translation>
    </message>
    <message>
        <source>Screensaver for ukui-screensaver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>show on root window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>show on window.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>window id</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>query the status of the screen saver</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
